/*
 * Software License Agreement (BSD License)
 *
 *  Copyright (c) 2020, Clearpath Robotics
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   * Neither the name of the copyright holder nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef FUSE_MODELS_PARAMETERS_GRAPH_IGNITION_PARAMS_H
#define FUSE_MODELS_PARAMETERS_GRAPH_IGNITION_PARAMS_H

#include <fuse_models/parameters/parameter_base.h>

#include <ros/node_handle.h>

#include <string>

namespace fuse_models
{

namespace parameters
{

/**
 * @brief Defines the set of parameters required by the GraphIgnition class
 */
struct GraphIgnitionParams : public fuse_models::parameters::ParameterBase
{
public:
  /**
   * @brief Method for loading parameter values from ROS.
   *
   * @param[in] nh - The ROS node handle with which to load parameters
   */
  void loadFromROS(const ros::NodeHandle& nh) final
  {
    nh.getParam("queue_size", queue_size);
    nh.getParam("reset_service", reset_service);
    nh.getParam("set_graph_service", set_graph_service);
    nh.getParam("topic", topic);
  }

  /**
   * @brief The size of the subscriber queue for the topic
   */
  int queue_size{ 10 };

  /**
   * @brief The name of the reset service to call before sending transactions to the optimizer
   */
  std::string reset_service{ "~reset" };

  /**
   * @brief The name of the set_graph service to advertise
   */
  std::string set_graph_service{ "~set_graph" };

  /**
   * @brief The topic name for received SerializedGraph messages
   */
  std::string topic{ "~graph" };
};

}  // namespace parameters

}  // namespace fuse_models

#endif  // FUSE_MODELS_PARAMETERS_GRAPH_IGNITION_PARAMS_H
